@@ -1,17 +1,27 @@
-/* File: main.h */
-
-/*
+/**
+ * \file main.h
+ * \brief Core game initialisation for UNIX (and other) machines
+ *
+ * Copyright (c) 1997 Ben Harrison, and others
  * Copyright (c) 2002 Robert Ruehlmann
  *
- * This software may be copied and distributed for educational, research,
- * and not for profit purposes provided that this copyright and statement
- * are included in all such copies.  Other copyrights may also apply.
+ * This work is free software; you can redistribute it and/or modify it
+ * under the terms of either:
+ *
+ * a) the GNU General Public License as published by the Free Software
+ *    Foundation, version 2, or
+ *
+ * b) the "Angband licence":
+ *    This software may be copied and distributed for educational, research,
+ *    and not for profit purposes provided that this copyright and statement
+ *    are included in all such copies.  Other copyrights may also apply.
  */
 
 #ifndef INCLUDED_MAIN_H
 #define INCLUDED_MAIN_H
 
 #include "angband.h"
+#include "ui-term.h"
 
 extern errr init_sound_sdl(int argc, char **argv);
 
@@ -52,6 +62,9 @@ extern const char help_sdl[];
 extern const char help_test[];
 extern const char help_stats[];
 
+//phantom server play
+extern bool arg_force_name;
+
 
 struct module
 {
