@@ -1,6 +1,6 @@
-/*
- * File: randname.c
- * Purpose: Random name generation
+/**
+ * \file randname.c
+ * \brief Random name generation
  *
  * Copyright (c) 2007 Antony Sidwell, Sheldon Simms
  *
@@ -15,6 +15,7 @@
  *    and not for profit purposes provided that this copyright and statement
  *    are included in all such copies.  Other copyrights may also apply.
  */
+
 #include "angband.h"
 #include "randname.h"
 
@@ -23,9 +24,15 @@
 #define E_WORD S_WORD
 #define TOTAL  27
 
+/**
+ * Array[RANDNAME_NUM_TYPES][num_names] of random names
+ */
+const char *** name_sections;
+
+
 typedef unsigned short name_probs[S_WORD+1][S_WORD+1][TOTAL+1];
 
-/*
+/**
  * This function builds probability tables from a list of purely alphabetical
  * lower-case words, and puts them into the supplied name_probs object.
  * The array of names should have a NULL entry at the end of the list.
@@ -38,14 +45,12 @@ static void build_prob(name_probs probs, const char **learn)
 	int i;
 
 	/* Build raw frequencies */
-	for (i = 0; learn[i] != NULL; i++)
-	{
+	for (i = 0; learn[i] != NULL; i++) {
 		c_prev = c_cur = S_WORD;
 		ch = learn[i];
 
 		/* Iterate over the next word */
-		while (*ch != '\0')
-		{
+		while (*ch != '\0') {
 			c_next = A2I(tolower((unsigned char)*ch));
 
 			probs[c_prev][c_cur][c_next]++;
@@ -62,14 +67,15 @@ static void build_prob(name_probs probs, const char **learn)
 	}
 }
 
-/*
+/**
  * Use W. Sheldon Simms' random name generator algorithm (Markov Chain stylee).
  * 
  * Generate a random word using the probability tables we built earlier.  
  * Relies on the A2I and I2A macros (and so the ASCII character set) and 
  * is_a_vowel (so the basic 5 English vowels).
  */
-size_t randname_make(randname_type name_type, size_t min, size_t max, char *word_buf, size_t buflen, const char ***sections)
+size_t randname_make(randname_type name_type, size_t min, size_t max,
+					 char *word_buf, size_t buflen, const char ***sections)
 {
 	size_t lnum = 0;
 	bool found_word = FALSE;
@@ -85,21 +91,19 @@ size_t randname_make(randname_type name_type, size_t min, size_t max, char *word
 	/* We cache one set of probabilities, only regenerate when
 	   the type changes.  It's as good a way as any for now.
 	   Frankly, we could probably regenerate every time. */
-	if (cached_type != name_type)
-	{
+	if (cached_type != name_type) {
 		const char **wordlist = NULL;
 
 		wordlist = sections[name_type];
 
-		(void)WIPE(lprobs, name_probs);
+		(void)memset(lprobs, 0, sizeof(name_probs));
 		build_prob(lprobs, wordlist);
 
 		cached_type = name_type;
 	}
         
 	/* Generate the actual word wanted. */
-	while (!found_word)
-	{
+	while (!found_word) {
 		char *cp = word_buf;
 		int c_prev = S_WORD;
 		int c_cur = S_WORD;
@@ -110,8 +114,7 @@ size_t randname_make(randname_type name_type, size_t min, size_t max, char *word
 		/* We start the word again if we run out of space or have
 		   had to have 10 goes to find a word that satisfies the
 		   minimal conditions. */
-		while (tries < 10 && lnum <= max && !found_word)
-		{
+		while (tries < 10 && lnum <= max && !found_word) {
 			/* Pick the next letter based on a simple weighting
 			  of which letters can follow the previous two */
 			int r;
@@ -122,8 +125,7 @@ size_t randname_make(randname_type name_type, size_t min, size_t max, char *word
 
 			r = randint0(lprobs[c_prev][c_cur][TOTAL]);
 
-			while (r >= lprobs[c_prev][c_cur][c_next])
-			{
+			while (r >= lprobs[c_prev][c_cur][c_next]) {
 				r -= lprobs[c_prev][c_cur][c_next];
 				c_next++;
 			}
@@ -131,24 +133,18 @@ size_t randname_make(randname_type name_type, size_t min, size_t max, char *word
 			assert(c_next <= E_WORD);
 			assert(c_next >= 0);
             
-			if (c_next == E_WORD)
-			{
+			if (c_next == E_WORD) {
 				/* If we've reached the end, we check if we've
 				   met the simple conditions, otherwise have
 				   another go at choosing a letter for this
 				   position. */
-				if (lnum >= min && contains_vowel)
-				{
+				if (lnum >= min && contains_vowel) {
 					*cp = '\0';
 					found_word = TRUE;
-				}
-				else
-				{
+				} else {
 					tries++;
 				}
-			}
-			else
-			{
+			} else {
 				/* Add the letter to the word and move on. */
 				*cp = I2A(c_next);
 
@@ -169,7 +165,7 @@ size_t randname_make(randname_type name_type, size_t min, size_t max, char *word
 }
 
 
-/* 
+/**
  * To run standalone tests, #define RANDNAME_TESTING and link with
  *  with just z-rand.c from Angband. 
  */
@@ -201,8 +197,7 @@ int main(int argc, char *argv[])
 
 	Rand_value = time(NULL);
 
-	for (i = 0; i < 20; i++)
-	{
+	for (i = 0; i < 20; i++) {
 		randname_make(RANDNAME_TOLKIEN, 5, 9, name, 256, name_sections);
 		my_strcap(name);
 		printf("%s\n", name);
