@@ -12,14 +12,15 @@
 #include "z-util.h"
 
 /*
- * Call this function to simulate init_stuff() and populate the *_info arrays
+ * Call this to initialise Angband's file paths before calling init_angband()
+ * or similar.
  */
-void read_edit_files(void) {
+void set_file_paths(void) {
 	char configpath[512], libpath[512], datapath[512];
 
 	my_strcpy(configpath, DEFAULT_CONFIG_PATH, sizeof(configpath));
-	my_strcpy(libpath,    DEFAULT_CONFIG_PATH, sizeof(libpath));
-	my_strcpy(datapath,   DEFAULT_CONFIG_PATH, sizeof(datapath));
+	my_strcpy(libpath, DEFAULT_LIB_PATH, sizeof(libpath));
+	my_strcpy(datapath, DEFAULT_DATA_PATH, sizeof(datapath));
 
 	configpath[511] = libpath[511] = datapath[511] = '\0';
 
@@ -31,5 +32,13 @@ void read_edit_files(void) {
 		my_strcat(datapath, PATH_SEP, sizeof(datapath));
 
 	init_file_paths(configpath, libpath, datapath);
+}
+
+/*
+ * Call this function to simulate init_stuff() and populate the *_info arrays
+ */
+void read_edit_files(void) {
+	set_file_paths();
+	init_game_constants();
 	init_arrays();
 }
