@@ -1,6 +1,6 @@
-/*
- * File: z-util.c
- * Purpose: Low-level string handling and other utilities.
+/**
+ * \file z-util.c
+ * \brief Low-level string handling and other utilities.
  *
  * Copyright (c) 1997-2005 Ben Harrison, Robert Ruehlmann.
  *
@@ -20,13 +20,17 @@
 
 #include "z-util.h"
 
-/*
+/**
  * Convenient storage of the program name
  */
 char *argv0 = NULL;
 
+/**
+ * Hook for platform-specific wide character handling
+ */
+size_t (*text_mbcs_hook)(wchar_t *dest, const char *src, int n) = NULL;
 
-/*
+/**
  * Count the number of characters in a UTF-8 encoded string
  *
  * Taken from http://canonical.org/~kragen/strlen-utf8.html
@@ -41,7 +45,7 @@ size_t utf8_strlen(char *s)
 	return j;
 }
 
-/*
+/**
  * Clip a null-terminated UTF-8 string 's' to 'n' unicode characters.
  * e.g. utf8_clipto("example", 4) will clip after 'm', resulting in 'exam'.
  */
@@ -68,7 +72,7 @@ void utf8_clipto(char *s, size_t n)
 	s[i] = 0;
 }
 
-/*
+/**
  * Case insensitive comparison between two strings
  */
 int my_stricmp(const char *s1, const char *s2)
@@ -77,11 +81,9 @@ int my_stricmp(const char *s1, const char *s2)
 	char ch2 = 0;
 
 	/* Just loop */
-	while (TRUE)
-	{
+	while (TRUE) {
 		/* We've reached the end of both strings simultaneously */
-		if ((*s1 == 0) && (*s2 == 0))
-		{
+		if ((*s1 == 0) && (*s2 == 0)) {
 			/* We're still here, so s1 and s2 are equal */
 			return (0);
 		}
@@ -90,8 +92,7 @@ int my_stricmp(const char *s1, const char *s2)
 		ch2 = toupper((unsigned char) *s2);
 
 		/* If the characters don't match */
-		if (ch1 != ch2)
-		{
+		if (ch1 != ch2) {
 			/* return the difference between them */
 			return ((int)(ch1 - ch2));
 		}
@@ -103,7 +104,7 @@ int my_stricmp(const char *s1, const char *s2)
 }
 
 
-/*
+/**
  * Case insensitive comparison between the first n characters of two strings
  */
 int my_strnicmp(const char *a, const char *b, int n)
@@ -112,8 +113,7 @@ int my_strnicmp(const char *a, const char *b, int n)
 	char z1, z2;
 
 	/* Scan the strings */
-	for (s1 = a, s2 = b; n > 0; s1++, s2++, n--)
-	{
+	for (s1 = a, s2 = b; n > 0; s1++, s2++, n--) {
 		z1 = toupper((unsigned char)*s1);
 		z2 = toupper((unsigned char)*s2);
 		if (z1 < z2) return (-1);
@@ -124,7 +124,7 @@ int my_strnicmp(const char *a, const char *b, int n)
 	return 0;
 }
 
-/*
+/**
  * An ANSI version of strstr() with case insensitivity.
  *
  * In the public domain; found at:
@@ -135,11 +135,9 @@ char *my_stristr(const char *string, const char *pattern)
 	const char *pptr, *sptr;
 	char *start;
 
-	for (start = (char *)string; *start != 0; start++)
-	{
-		/* find start of pattern in string */
-		for ( ; ((*start != 0) &&
-			 (toupper((unsigned char)*start) != toupper((unsigned char)*pattern))); start++)
+	for (start = (char *)string; *start != 0; start++) {
+		/* Find start of pattern in string */
+		for ( ; ((*start != 0) && (toupper((unsigned char)*start) != toupper((unsigned char)*pattern))); start++)
 			;
 		if (*start == 0)
 			return NULL;
@@ -147,12 +145,11 @@ char *my_stristr(const char *string, const char *pattern)
 		pptr = (const char *)pattern;
 		sptr = (const char *)start;
 
-		while (toupper((unsigned char)*sptr) == toupper((unsigned char)*pptr))
-		{
+		while (toupper((unsigned char)*sptr) == toupper((unsigned char)*pptr)) {
 			sptr++;
 			pptr++;
 
-			/* if end of pattern then pattern was found */
+			/* If end of pattern then pattern was found */
 			if (*pptr == 0)
 				return (start);
 		}
@@ -162,7 +159,7 @@ char *my_stristr(const char *string, const char *pattern)
 }
 
 
-/*
+/**
  * The my_strcpy() function copies up to 'bufsize'-1 characters from 'src'
  * to 'buf' and NUL-terminates the result.  The 'buf' and 'src' strings may
  * not overlap.
@@ -192,10 +189,11 @@ size_t my_strcpy(char *buf, const char *src, size_t bufsize)
 }
 
 
-/*
- * The my_strcat() tries to append a string to an existing NUL-terminated string.
- * It never writes more characters into the buffer than indicated by 'bufsize' and
- * NUL-terminates the buffer.  The 'buf' and 'src' strings may not overlap.
+/**
+ * The my_strcat() tries to append a string to an existing NUL-terminated
+ * string.
+ * It never writes more characters into the buffer than indicated by 'bufsize'
+ * and NUL-terminates the buffer.  The 'buf' and 'src' strings may not overlap.
  *
  * my_strcat() returns strlen(buf) + strlen(src).  This makes checking for
  * truncation easy.  Example:
@@ -208,13 +206,10 @@ size_t my_strcat(char *buf, const char *src, size_t bufsize)
 	size_t dlen = strlen(buf);
 
 	/* Is there room left in the buffer? */
-	if (dlen < bufsize - 1)
-	{
+	if (dlen < bufsize - 1) {
 		/* Append as much as possible  */
 		return (dlen + my_strcpy(buf + dlen, src, bufsize - dlen));
-	}
-	else
-	{
+	} else {
 		/* Return without appending */
 		return (dlen + strlen(src));
 	}
@@ -230,7 +225,7 @@ void my_strcap(char *buf)
 }
 
 
-/*
+/**
  * Determine if string "a" is equal to string "b"
  */
 #undef streq
@@ -240,7 +235,7 @@ bool streq(const char *a, const char *b)
 }
 
 
-/*
+/**
  * Determine if string "t" is a suffix of string "s"
  */
 bool suffix(const char *s, const char *t)
@@ -256,7 +251,7 @@ bool suffix(const char *s, const char *t)
 }
 
 
-/*
+/**
  * Determine if string "t" is a prefix of string "s"
  */
 bool prefix(const char *s, const char *t)
@@ -273,7 +268,7 @@ bool prefix(const char *s, const char *t)
 }
 
 
-/*
+/**
  * Determine if string "t" is a prefix of string "s" - case insensitive.
  */
 bool prefix_i(const char *s, const char *t)
@@ -294,33 +289,49 @@ bool prefix_i(const char *s, const char *t)
 	return (TRUE);
 }
 
-/*
- * rewrite string s in-place "skipping" every occurrence of character c
+/**
+ * Rewrite string s in-place "skipping" every occurrence of character c except
+ * those preceded by character e
  */
-void strskip(char *s, const char c){
-	char *in=s;
-	char *out=s;
-	while(*in){
-		if(*in!=c){
-			*out=*in;
+void strskip(char *s, const char c, const char e) {
+	char *in = s;
+	char *out = s;
+	bool escapeseen = FALSE;
+	while (*in) {
+		if ((*in != c) && ((*in != e) || escapeseen)) {
+			if (escapeseen) {
+				/* Not escaping anything */
+				*out = e;
+				out++;
+			}
+			*out = *in;
 			out++;
+			escapeseen = FALSE;
+		} else if (*in == e) {
+			/* Maybe escaping something */
+			escapeseen = TRUE;
+		} else if (escapeseen) {
+			/* Add the escaped character */
+			*out = *in;
+			out++;
+			escapeseen = FALSE;
 		}
 		in++;
 	}
-	*out=0;
+	*out = 0;
 }
 
-/*
- * rewrite string s in-place removing escape character c
+/**
+ * Rewrite string s in-place removing escape character c
  * note that pairs of c will leave one instance of c in out
  */
-void strescape(char *s, const char c){
-	char *in=s;
-	char *out=s;
+void strescape(char *s, const char c) {
+	char *in = s;
+	char *out = s;
 	bool escapenext = FALSE;
-	while(*in){
-		if(*in!=c || escapenext){
-			*out=*in;
+	while (*in) {
+		if (*in != c || escapenext) {
+			*out = *in;
 			out++;
 			escapenext = FALSE;
 		} else if (*in == c) {
@@ -328,10 +339,10 @@ void strescape(char *s, const char c){
 		}
 		in++;
 	}
-	*out=0;
+	*out = 0;
 }
 
-/*
+/**
  * returns TRUE if string only contains spaces
  */
 bool contains_only_spaces(const char* s){
@@ -344,7 +355,38 @@ bool contains_only_spaces(const char* s){
 	return TRUE;
 }
 
-/*
+/**
+ * Check a char for "vowel-hood"
+ */
+bool is_a_vowel(int ch)
+{
+	switch (tolower((unsigned char) ch))
+	{
+		case 'a':
+		case 'e':
+		case 'i':
+		case 'o':
+		case 'u':
+		{
+			return (TRUE);
+		}
+	}
+
+	return (FALSE);
+}
+
+/**
+ * Allow override of the multi-byte to wide char conversion
+ */
+size_t text_mbstowcs(wchar_t *dest, const char *src, int n)
+{
+	if (text_mbcs_hook)
+		return (*text_mbcs_hook)(dest, src, n);
+	else
+		return mbstowcs(dest, src, n);
+}
+
+/**
  * Redefinable "plog" action
  */
 void (*plog_aux)(const char *) = NULL;
@@ -364,12 +406,12 @@ void plog(const char *str)
 
 
 
-/*
+/**
  * Redefinable "quit" action
  */
 void (*quit_aux)(const char *) = NULL;
 
-/*
+/**
  * Exit (ala "exit()").  If 'str' is NULL, do "exit(EXIT_SUCCESS)".
  * Otherwise, plog() 'str' and exit with an error code of -1.
  * But always use 'quit_aux', if set, before anything else.
@@ -389,7 +431,9 @@ void quit(const char *str)
 	exit(EXIT_FAILURE);
 }
 
-/* Arithmetic mean of the first 'size' entries of the array 'nums' */
+/**
+ * Arithmetic mean of the first 'size' entries of the array 'nums'
+ */
 int mean(int *nums, int size)
 {
 	int i, total = 0;
@@ -399,7 +443,9 @@ int mean(int *nums, int size)
 	return total / size;
 }
 
-/* Variance of the first 'size' entries of the array 'nums'  */
+/**
+ * Variance of the first 'size' entries of the array 'nums'
+ */
 int variance(int *nums, int size)
 {
 	int i, avg, total = 0;
